aboutsummaryrefslogtreecommitdiffstats
path: root/java/org/tinyb/BluetoothAdapter.java
diff options
context:
space:
mode:
Diffstat (limited to 'java/org/tinyb/BluetoothAdapter.java')
-rw-r--r--java/org/tinyb/BluetoothAdapter.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/java/org/tinyb/BluetoothAdapter.java b/java/org/tinyb/BluetoothAdapter.java
index 4a989500..bf608e90 100644
--- a/java/org/tinyb/BluetoothAdapter.java
+++ b/java/org/tinyb/BluetoothAdapter.java
@@ -242,10 +242,10 @@ public interface BluetoothAdapter extends BluetoothObject
public boolean getDiscovering();
/**
* Sets the {@link BluetoothDeviceStatusListener} for the respective device status events.
* @param listener A {@link BluetoothDeviceStatusListener} instance, or {@code null} to disable notifications.
*/
- public void setDeviceStatusListener(final BluetoothDeviceStatusListener listener);
+ public void setStatusListener(final BluetoothAdapterStatusListener listener);
/**
* Enables notifications for the discovering property and calls run function of the
@@ -242,10 +242,10 @@ public interface BluetoothAdapter extends BluetoothObject
public boolean getDiscovering();
/**
- * Sets the {@link BluetoothDeviceStatusListener} for the respective device status events.
- * @param listener A {@link BluetoothDeviceStatusListener} instance, or {@code null} to disable notifications.
+ * Sets the {@link BluetoothAdapterStatusListener} for the respective device status events.
+ * @param listener A {@link BluetoothAdapterStatusListener} instance, or {@code null} to disable notifications.
*/